from django.apps import AppConfig


class DjangoSwapUser(AppConfig):
    name = "swap_user"
    verbose_name = "Django Swap User"
